@@ -25,13 +25,13 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-message-area.h 5666 2007-06-29 19:52:25Z sfre $
+ * $Id: gedit-message-area.h 6631 2008-11-29 11:06:49Z pborelli $
  */
 
 #ifndef __GEDIT_MESSAGE_AREA_H__
 #define __GEDIT_MESSAGE_AREA_H__
 
-#include <gtk/gtkdialog.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
