@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window-private.h 6770 2008-12-31 12:13:00Z jessevdk $
+ * $Id: gedit-window-private.h 6832 2009-01-10 14:39:17Z icq $
  */
 
 #ifndef __GEDIT_WINDOW_PRIVATE_H__
@@ -54,6 +54,11 @@ struct _GeditWindowPrivate
 	
 	GeditMessageBus *message_bus;	
 
+	/* Widgets for fullscreen mode */
+	GtkWidget      *fullscreen_controls;
+	guint           fullscreen_animation_timeout_id;
+	gboolean        fullscreen_animation_enter;
+
 	/* statusbar and context ids for statusbar messages */
 	GtkWidget      *statusbar;	
 	guint           generic_message_cid;
