@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window.h 6755 2008-12-29 18:52:22Z jessevdk $
+ * $Id: gedit-window.h 6819 2009-01-07 14:56:55Z icq $
  */
 
 #ifndef __GEDIT_WINDOW_H__
@@ -178,6 +178,12 @@ void		 _gedit_window_set_default_path 	(GeditWindow         *window,
 void		 _gedit_window_set_saving_session_state	(GeditWindow         *window,
 							 gboolean             saving_session);
 
+void		 _gedit_window_fullscreen		(GeditWindow         *window);
+
+void		 _gedit_window_unfullscreen		(GeditWindow         *window);
+
+gboolean	 _gedit_window_is_fullscreen		(GeditWindow         *window);
+
 /* these are in gedit-window because of screen safety */
 void		 _gedit_recent_add			(GeditWindow	     *window,
 							 const gchar         *uri,
