@@ -81,6 +81,13 @@ struct _AsyncNode
 	GSList *original_children;
 };
 
+typedef struct {
+	GeditFileBrowserStore * model;
+	gchar * virtual_root;
+	GMountOperation * operation;
+	GCancellable * cancellable;
+} MountInfo;
+
 struct _FileBrowserNode 
 {
 	GFile *file;
@@ -119,6 +126,7 @@ struct _GeditFileBrowserStorePrivate
 	SortFunc sort_func;
 
 	GSList *async_handles;
+	MountInfo *mount_info;
 };
 
 static FileBrowserNode *model_find_node 		    (GeditFileBrowserStore *model,
@@ -223,6 +231,17 @@ enum
 
 static guint model_signals[NUM_SIGNALS] = { 0 };
 
+static void
+cancel_mount_operation (GeditFileBrowserStore *obj)
+{
+	if (obj->priv->mount_info != NULL)
+	{
+		obj->priv->mount_info->model = NULL;
+		g_cancellable_cancel (obj->priv->mount_info->cancellable);
+		obj->priv->mount_info = NULL;
+	}
+}
+
 static void
 gedit_file_browser_store_finalize (GObject * object)
 {
@@ -240,6 +259,8 @@ gedit_file_browser_store_finalize (GObject * object)
 		
 		data->removed = TRUE;
 	}
+	
+	cancel_mount_operation (obj);
 
 	g_slist_free (obj->priv->async_handles);
 	G_OBJECT_CLASS (gedit_file_browser_store_parent_class)->finalize (object);
@@ -609,7 +630,7 @@ gedit_file_browser_store_get_path_real (GeditFileBrowserStore * model,
 
 			check = (FileBrowserNode *) (item->data);
 
-			if (model_node_visibility (model, check)) {
+			if (model_node_visibility (model, check) && (check == node || check->inserted)) {
 				if (check == node) {
 					gtk_tree_path_prepend_index (path,
 								     num);
@@ -1401,7 +1422,7 @@ model_remove_node_children (GeditFileBrowserStore * model,
 		
 		return;
 	}
-
+	
 	if (path == NULL)
 		path_child =
 		    gedit_file_browser_store_get_path_real (model, node);
@@ -1706,7 +1727,7 @@ model_check_dummy (GeditFileBrowserStore * model, FileBrowserNode * node)
 				path =
 				    gedit_file_browser_store_get_path_real
 				    (model, dummy);
-
+				    
 				row_inserted (model, &path, &iter);
 				gtk_tree_path_free (path);
 			}
@@ -2225,16 +2246,25 @@ model_iterate_next_files_cb (GFileEnumerator * enumerator,
 			g_object_unref (dir->cancellable);
 			dir->cancellable = NULL;
 			
+/*
+ * FIXME: This is temporarly, it is a bug in gio:
+ * http://bugzilla.gnome.org/show_bug.cgi?id=565924
+ */
+#ifndef G_OS_WIN32
 			if (g_file_is_native (parent->file) && dir->monitor == NULL) {
 				dir->monitor = g_file_monitor_directory (parent->file, 
 									 G_FILE_MONITOR_NONE,
 									 NULL,
 									 NULL);
-				g_signal_connect (dir->monitor,
-						  "changed",
-						  G_CALLBACK (on_directory_monitor_event),
-						  parent);
+				if (dir->monitor != NULL)
+				{
+					g_signal_connect (dir->monitor,
+							  "changed",
+							  G_CALLBACK (on_directory_monitor_event),
+							  parent);
+				}
 			}
+#endif
 
 			model_check_dummy (dir->model, parent);
 			model_end_loading (dir->model, parent);
@@ -2371,7 +2401,7 @@ get_parent_files (GeditFileBrowserStore * model, GFile * file)
 
 static void
 model_fill (GeditFileBrowserStore * model, FileBrowserNode * node,
-	    GtkTreePath * path)
+	    GtkTreePath ** path)
 {
 	gboolean free_path = FALSE;
 	GtkTreeIter iter = {0,};
@@ -2380,19 +2410,19 @@ model_fill (GeditFileBrowserStore * model, FileBrowserNode * node,
 
 	if (node == NULL) {
 		node = model->priv->virtual_root;
-		path = gtk_tree_path_new ();
+		*path = gtk_tree_path_new ();
 		free_path = TRUE;
 	}
 
-	if (path == NULL) {
-		path =
+	if (*path == NULL) {
+		*path =
 		    gedit_file_browser_store_get_path_real (model, node);
 		free_path = TRUE;
 	}
 
 	if (!model_node_visibility (model, node)) {
 		if (free_path)
-			gtk_tree_path_free (path);
+			gtk_tree_path_free (*path);
 
 		return;
 	}
@@ -2401,12 +2431,12 @@ model_fill (GeditFileBrowserStore * model, FileBrowserNode * node,
 		/* Insert node */
 		iter.user_data = node;
 		
-		row_inserted(model, &path, &iter);
+		row_inserted(model, path, &iter);
 	}
 
 	if (NODE_IS_DIR (node)) {
 		/* Go to the first child */
-		gtk_tree_path_down (path);
+		gtk_tree_path_down (*path);
 
 		for (item = FILE_BROWSER_NODE_DIR (node)->children; item;
 		     item = item->next) {
@@ -2416,18 +2446,18 @@ model_fill (GeditFileBrowserStore * model, FileBrowserNode * node,
 				model_fill (model, child, path);
 
 				/* Increase path for next child */
-				gtk_tree_path_next (path);
+				gtk_tree_path_next (*path);
 			}
 		}
 
 		/* Move back up to node path */
-		gtk_tree_path_up (path);
+		gtk_tree_path_up (*path);
 	}
 	
 	model_check_dummy (model, node);
 
 	if (free_path)
-		gtk_tree_path_free (path);
+		gtk_tree_path_free (*path);
 }
 
 static void
@@ -2440,6 +2470,7 @@ set_virtual_root_from_node (GeditFileBrowserStore * model,
 	FileBrowserNodeDir *dir;
 	GSList *item;
 	GSList *copy;
+	GtkTreePath *empty = NULL;
 
 	prev = node;
 	next = prev->parent;
@@ -2504,7 +2535,7 @@ set_virtual_root_from_node (GeditFileBrowserStore * model,
 
 	/* Now finally, set the virtual root, and load it up! */
 	model->priv->virtual_root = node;
-	model_fill (model, NULL, NULL);
+	model_fill (model, NULL, &empty);
 
 	if (!NODE_LOADED (node))
 		model_load_directory (model, node);
@@ -2637,14 +2668,6 @@ model_root_mounted (GeditFileBrowserStore * model, gchar const * virtual_root)
 	return GEDIT_FILE_BROWSER_STORE_RESULT_OK;
 }
 
-typedef struct {
-	GeditFileBrowserStore * model;
-	gchar * virtual_root;
-	GMountOperation * operation;
-	GCancellable * cancellable;
-} MountInfo;
-
-
 static void
 handle_root_error (GeditFileBrowserStore * model, GError *error)
 {
@@ -2680,12 +2703,15 @@ mount_cb (GFile * file,
 	GeditFileBrowserStore * model = mount_info->model;
 	
 	mounted = g_file_mount_enclosing_volume_finish (file, res, &error);
-	
-	if (g_cancellable_is_cancelled (mount_info->cancellable))
+
+	if (mount_info->model)
+	{
+		model->priv->mount_info = NULL;	
+		model_end_loading (model, model->priv->root);
+	}
+
+	if (!mount_info->model || g_cancellable_is_cancelled (mount_info->cancellable))
 	{
-		if (error)
-			g_error_free (error);
-		
 		// Reset because it might be reused?
 		g_cancellable_reset (mount_info->cancellable);
 	}
@@ -2734,12 +2760,16 @@ model_mount_root (GeditFileBrowserStore * model, gchar const * virtual_root)
 			mount_info->operation = gtk_mount_operation_new (NULL);
 			mount_info->cancellable = g_object_ref (FILE_BROWSER_NODE_DIR (model->priv->root)->cancellable);
 			
+			model_begin_loading (model, model->priv->root);
 			g_file_mount_enclosing_volume (model->priv->root->file, 
 						       G_MOUNT_MOUNT_NONE,
 						       mount_info->operation,
 						       mount_info->cancellable,
 						       (GAsyncReadyCallback)mount_cb,
 						       mount_info);
+			
+			model->priv->mount_info = mount_info;
+			return GEDIT_FILE_BROWSER_STORE_RESULT_MOUNTING;
 		}
 		else
 		{
@@ -2957,6 +2987,14 @@ gedit_file_browser_store_iter_equal (GeditFileBrowserStore * model,
 	return (iter1->user_data == iter2->user_data);
 }
 
+void
+gedit_file_browser_store_cancel_mount_operation (GeditFileBrowserStore *store)
+{
+	g_return_if_fail (GEDIT_IS_FILE_BROWSER_STORE (store));
+	
+	cancel_mount_operation (store);
+}
+
 GeditFileBrowserStoreResult
 gedit_file_browser_store_set_root_and_virtual_root (GeditFileBrowserStore *
 						    model,
@@ -3000,6 +3038,9 @@ gedit_file_browser_store_set_root_and_virtual_root (GeditFileBrowserStore *
 
 		g_object_unref (vfile);
 	}
+	
+	/* make sure to cancel any previous mount operations */
+	cancel_mount_operation (model);
 
 	/* Always clear the model before altering the nodes */
 	model_clear (model, TRUE);
